#' Cached ADSL
#'
#' Cached ADSL data
#'
#' @docType data
#'
#' @usage data(eg_adsl)
"eg_adsl"

#' Cached ADAE
#'
#' Cached ADAE data
#'
#' @docType data
#'
#' @usage data(eg_adae)
"eg_adae"

#' Cached ADTTE
#'
#' Cached ADTTE data
#'
#' @docType data
#'
#' @usage data(eg_adtte)
"eg_adtte"

#' Cached ADEX
#'
#' Cached ADEX data
#'
#' @docType data
#'
#' @usage data(eg_adex)
"eg_adex"

#' Cached ADEG
#'
#' Cached ADEG data
#'
#' @docType data
#'
#' @usage data(eg_adeg)
"eg_adeg"

#' Cached ADVS
#'
#' Cached ADVS data
#'
#' @docType data
#'
#' @usage data(eg_advs)
"eg_advs"

#' Cached ADLB
#'
#' Cached
#' ADLB data
#'
#' @docType data
#'
#' @usage data(eg_adlb)
"eg_adlb"

#' Cached ADRS
#'
#' Cached ADRS data
#'
#' @docType data
#'
#' @usage data(eg_adrs)
"eg_adrs"


#' Cached ADTR
#'
#' Cached ADTR data
#'
#' @docType data
#'
#' @usage data(eg_adtr)
"eg_adtr"


#' Cached trial
#'
#' Cached trial data
#'
#' @docType data
#'
#' @export
trial <- gtsummary::trial
